"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.raConfigureGenerator = void 0;
const path_1 = __importDefault(require("path"));
const inquirer_autocomplete_prompt_1 = __importDefault(require("inquirer-autocomplete-prompt"));
const defaultConfigureGenerator_1 = require("./defaultConfigureGenerator");
const utils_1 = require("../../../common/utils");
const raConfigureGenerator = async (templateDir, gen, options) => {
    if ('dest' in options || 'dirShift' in options) {
        throw new Error(`Options 'dest' and 'dirShift' should NOT be used for react-admin generators, `
            + ` use 'appPath' and 'screenPath' instead, `
            + `for details see https://github.com/Amplicode/amplicode-frontend/#react-admin-app-generator`);
    }
    const { appPath, screenPath } = options;
    if (appPath == null) {
        throw new Error(`Option 'appPath' is required for react-admin generators`);
    }
    let destinationPath = path_1.default.isAbsolute(appPath) ? appPath : path_1.default.join(gen.destinationRoot(), appPath);
    if (!utils_1.isBlank(screenPath)) {
        destinationPath = path_1.default.join(destinationPath, screenPath);
    }
    gen.log(`raConfigureGenerator, set destinationRoot to '${destinationPath}'`);
    gen.destinationRoot(destinationPath);
    // const {templateOverride} = options;
    // gen.sourceRoot(templateOverride ?? templateDir);
    gen.sourceRoot(templateDir);
    // @ts-ignore this.env.adapter is missing in the typings
    gen.env.adapter
        .promptModule.registerPrompt('autocomplete', inquirer_autocomplete_prompt_1.default);
    gen.registerTransformStream(defaultConfigureGenerator_1.createEjsRenameTransform());
    gen.registerTransformStream(defaultConfigureGenerator_1.createFormatTransform());
    // Never ask for confirmation when overwriting files,
    // since currently we only support using generator from Studio.
    // If in future we decide to support using generator from CLI, we need to revisit this.
    gen.conflicter.force = true;
};
exports.raConfigureGenerator = raConfigureGenerator;
//# sourceMappingURL=raConfigureGenerator.js.map